@@ -6,12 +6,12 @@ MCP HTTP 服务器请求处理器
 import logging
 from datetime import datetime
 from aiohttp import web
-from typing import Dict, Any
+from typing import Dict, Any, Union
 import json
 import asyncio
 
 from ..core.base import BaseMCPServer
-from ..core.config import ConfigManager
+from ..core.config import ConfigManager, ServerConfigAdapter
 
 logger = logging.getLogger(__name__)
 
@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 class MCPRequestHandler:
     """MCP 请求处理器"""
 
-    def __init__(self, mcp_server: BaseMCPServer, config_manager: ConfigManager):
+    def __init__(self, mcp_server: BaseMCPServer, config_manager: Union[ConfigManager, ServerConfigAdapter]):
         self.mcp_server = mcp_server
         self.config_manager = config_manager
         self.start_time = datetime.now()
@@ -38,7 +38,7 @@ class MCPRequestHandler:
             if method == 'initialize':
                 result = await self.handle_initialize(params)
             elif method == 'tools/list':
-                result = await self.handle_tools_list()
+                result = await self.handle_tools_list(params)
             elif method == 'tools/call':
                 result = await self.handle_tool_call(params)
             elif method == 'resources/list':
@@ -83,11 +83,33 @@ class MCPRequestHandler:
             }
         }
 
-    async def handle_tools_list(self):
+    async def handle_tools_list(self, params=None):
         """处理工具列表请求"""
-        return {
-            'tools': self.mcp_server.tools
-        }
+        # 获取role参数
+        role = params.get('role') if params else None
+        
+        if role:
+            # 如果指定了role，返回匹配该role的工具和没有role的工具
+            filtered_tools = []
+            for tool in self.mcp_server.tools:
+                # 检查新的roles数组格式
+                if 'roles' in tool and tool['roles']:
+                    if role in tool['roles']:
+                        filtered_tools.append(tool)
+                # 向后兼容：检查旧的role格式
+                elif tool.get('role') == role:
+                    filtered_tools.append(tool)
+                # 没有角色限制的工具（通用工具）
+                elif tool.get('role') is None and tool.get('roles') is None:
+                    filtered_tools.append(tool)
+            return {
+                'tools': filtered_tools
+            }
+        else:
+            # 如果没有指定role，返回所有工具
+            return {
+                'tools': self.mcp_server.tools
+            }
 
     def _coerce_value(self, value, expected_type: str):
         """根据期望类型转换单个值"""
@@ -383,6 +405,17 @@ class SSEHandler:
 
     async def handle_sse_tool_call(self, request):
         """处理 SSE 工具调用请求"""
+        # 先创建 SSE 响应，确保所有错误都能通过 SSE 事件返回
+        response = web.StreamResponse()
+        response.headers['Content-Type'] = 'text/event-stream'
+        response.headers['Cache-Control'] = 'no-cache'
+        response.headers['Connection'] = 'keep-alive'
+        response.headers['Access-Control-Allow-Origin'] = '*'
+        response.headers['Access-Control-Allow-Headers'] = 'Cache-Control'
+        
+        await response.prepare(request)
+        
+        session_id = None
         try:
             # 获取查询参数或 POST 数据
             if request.method == 'POST':
@@ -429,23 +462,14 @@ class SSEHandler:
                 self.logger.info(f"After coercion: {arguments}")
             except Exception as e:
                 self.logger.warning(f"Failed to coerce arguments for tool '{tool_name}': {e}")
-                raise ValueError(f"Tool '{tool_name}' parameter '{e}'")
+                raise ValueError(f"Tool '{tool_name}' missing required parameter: {str(e).split(': ')[-1] if ': ' in str(e) else str(e)}")
 
             # 创建流式会话
             session_id = self.mcp_server.start_streaming_session()
-
-            # 创建 SSE 响应
-            response = web.StreamResponse()
-            response.headers['Content-Type'] = 'text/event-stream'
-            response.headers['Cache-Control'] = 'no-cache'
-            response.headers['Connection'] = 'keep-alive'
-            response.headers['Access-Control-Allow-Origin'] = '*'
-            response.headers['Access-Control-Allow-Headers'] = 'Cache-Control'
+            
             # 添加会话ID到响应头
             response.headers['X-Session-ID'] = session_id
 
-            await response.prepare(request)
-
             # 发送开始事件，包含会话ID
             if not await self._send_sse_event(response, 'start', {
                 'tool_name': tool_name,
@@ -500,13 +524,17 @@ class SSEHandler:
 
         except Exception as e:
             self.logger.error(f"SSE tool call error: {str(e)}")
-            # 对于初始化错误，返回普通 HTTP 错误响应
-            return web.json_response({
-                'error': {
-                    'code': 'SSE_ERROR',
-                    'message': str(e)
-                }
-            }, status=400)
+            # 通过 SSE 事件发送错误信息，而不是返回 JSON 响应
+            await self._send_sse_event(response, 'error', {
+                'error': str(e),
+                'code': 'SSE_INIT_ERROR',
+                'session_id': session_id
+            })
+            # 清理会话（如果已创建）
+            if session_id:
+                self.mcp_server.cleanup_streaming_session(session_id)
+        
+        return response
 
     async def _send_sse_event(self, response, event_type: str, data: dict):
         """发送 SSE 事件"""
@@ -569,12 +597,121 @@ class SSEHandler:
             pass
 
         return response
+    
+    async def handle_sse_tool_call_openai(self, request):
+        """处理 OpenAI 格式的 SSE 工具调用请求"""
+        # 创建 SSE 响应
+        response = web.StreamResponse()
+        response.headers['Content-Type'] = 'text/event-stream'
+        response.headers['Cache-Control'] = 'no-cache'
+        response.headers['Connection'] = 'keep-alive'
+        response.headers['Access-Control-Allow-Origin'] = '*'
+        response.headers['Access-Control-Allow-Headers'] = 'Cache-Control'
+        
+        await response.prepare(request)
+        
+        session_id = None
+        try:
+            # 获取查询参数或 POST 数据
+            if request.method == 'POST':
+                data = await request.json()
+                tool_name = data.get('tool_name')
+                arguments = data.get('arguments', {})
+            else:
+                # GET 请求，从查询参数获取
+                tool_name = request.query.get('tool_name')
+                arguments_str = request.query.get('arguments')
+
+                if arguments_str:
+                    try:
+                        arguments = json.loads(arguments_str)
+                    except json.JSONDecodeError:
+                        arguments = {}
+                        for key, value in request.query.items():
+                            if key != 'tool_name':
+                                arguments[key] = value
+                else:
+                    arguments = {}
+                    for key, value in request.query.items():
+                        if key != 'tool_name':
+                            arguments[key] = value
+
+            self.logger.info(f"OpenAI SSE tool call - tool_name: {tool_name}, arguments: {arguments}")
+
+            if not tool_name:
+                raise ValueError("Tool name is required")
+
+            # 检查工具是否存在
+            tool_exists = any(tool['name'] == tool_name for tool in self.mcp_server.tools)
+            if not tool_exists:
+                raise ValueError(f"Tool '{tool_name}' not found")
+
+            # 基于工具 schema 对参数进行类型转换和默认值填充
+            try:
+                arguments = self._coerce_arguments_with_schema(tool_name, arguments)
+            except Exception as e:
+                raise ValueError(f"Tool '{tool_name}' missing required parameter: {str(e).split(': ')[-1] if ': ' in str(e) else str(e)}")
+
+            # 创建流式会话
+            session_id = self.mcp_server.start_streaming_session()
+            
+            # 添加会话ID到响应头
+            response.headers['X-Session-ID'] = session_id
+
+            try:
+                # 使用OpenAI格式的流式处理
+                async for openai_chunk in self.mcp_server.handle_tool_call_stream_openai(tool_name, arguments, session_id):
+                    # 检查是否应该停止
+                    if self.mcp_server.is_streaming_stopped(session_id):
+                        # 发送停止事件
+                        await response.write(b"data: [DONE]\n\n")
+                        break
+
+                    # 直接写入OpenAI格式的SSE数据
+                    try:
+                        await response.write(openai_chunk.encode('utf-8'))
+                        await response.drain()
+                    except Exception as write_error:
+                        self.logger.warning(f"Failed to write OpenAI SSE data: {write_error}")
+                        break
+                    
+                    await asyncio.sleep(0.01)  # 小延迟避免过快发送
+
+                # 发送完成标记
+                await response.write(b"data: [DONE]\n\n")
+
+            except Exception as e:
+                # 发送错误事件（OpenAI格式）
+                from ..core.streaming import OpenAIStreamFormatter
+                formatter = OpenAIStreamFormatter(f"{self.mcp_server.name}-{self.mcp_server.version}", session_id)
+                error_chunk = formatter.create_error_chunk(str(e))
+                await response.write(error_chunk.to_sse_data().encode('utf-8'))
+            finally:
+                # 清理会话
+                if session_id:
+                    self.mcp_server.cleanup_streaming_session(session_id)
+
+            return response
+
+        except Exception as e:
+            self.logger.error(f"OpenAI SSE tool call error: {str(e)}")
+            # 发送错误事件
+            from ..core.streaming import OpenAIStreamFormatter
+            formatter = OpenAIStreamFormatter(f"{self.mcp_server.name}-{self.mcp_server.version}", session_id)
+            error_chunk = formatter.create_error_chunk(str(e))
+            await response.write(error_chunk.to_sse_data().encode('utf-8'))
+            
+            # 清理会话（如果已创建）
+            if session_id:
+                self.mcp_server.cleanup_streaming_session(session_id)
+        
+        return response
 
 
 class APIHandler:
     """API 处理器"""
 
-    def __init__(self, mcp_server: BaseMCPServer, config_manager: ConfigManager):
+    def __init__(self, mcp_server: BaseMCPServer, config_manager: Union[ConfigManager, ServerConfigAdapter]):
         self.mcp_server = mcp_server
         self.config_manager = config_manager
         self.start_time = datetime.now()
@@ -621,10 +758,45 @@ class APIHandler:
             'features': ['tools', 'resources', 'streaming', 'sse']  # 新增特性列表
         })
 
+    async def tools_list(self, request):
+        """工具列表 - 支持role参数过滤"""
+        # 获取role查询参数
+        role = request.query.get('role')
+        
+        if role:
+            # 如果指定了role，返回匹配该role的工具和没有role的工具
+            filtered_tools = []
+            for tool in self.mcp_server.tools:
+                # 检查新的roles数组格式
+                if 'roles' in tool and tool['roles']:
+                    if role in tool['roles']:
+                        filtered_tools.append(tool)
+                # 向后兼容：检查旧的role格式
+                elif tool.get('role') == role:
+                    filtered_tools.append(tool)
+                # 没有角色限制的工具（通用工具）
+                elif tool.get('role') is None and tool.get('roles') is None:
+                    filtered_tools.append(tool)
+            return web.json_response({
+                'tools': filtered_tools
+            })
+        else:
+            # 如果没有指定role，返回所有工具
+            return web.json_response({
+                'tools': self.mcp_server.tools
+            })
+
     async def get_config(self, request):
-        """获取配置"""
+        """获取当前配置"""
         config = self.config_manager.load_config()
-        return web.json_response(config.to_dict())
+        config_dict = config.to_dict()
+        
+        # 如果使用的是 ServerConfigAdapter，添加别名信息
+        if hasattr(self.config_manager, 'server_config_manager'):
+            server_config_manager = self.config_manager.server_config_manager
+            config_dict['alias'] = getattr(server_config_manager, 'alias', None)
+        
+        return web.json_response(config_dict)
 
     async def update_config(self, request):
         """更新配置"""
@@ -633,7 +805,11 @@ class APIHandler:
 
             # 加载当前配置
             current_config = self.config_manager.load_config()
+            old_config_dict = current_config.to_dict()
 
+            # 分离别名和其他配置项
+            alias_value = data.pop('alias', None)
+            
             # 更新配置
             for key, value in data.items():
                 if hasattr(current_config, key):
@@ -641,6 +817,17 @@ class APIHandler:
 
             # 保存配置
             if self.config_manager.save_config(current_config):
+                # 如果有别名更新且使用的是 ServerConfigAdapter，更新别名
+                if alias_value is not None and hasattr(self.config_manager, 'server_config_manager'):
+                    server_config_manager = self.config_manager.server_config_manager
+                    server_config_manager.alias = alias_value
+                    self.logger.info(f"别名已更新为: {alias_value}")
+                
+                # 通知MCP服务器配置更新（如果配置项与服务器参数相关）
+                new_config_dict = current_config.to_dict()
+                if hasattr(self.mcp_server, '_notify_config_update'):
+                    self.mcp_server._notify_config_update(old_config_dict, new_config_dict)
+                
                 return web.json_response({
                     'success': True,
                     'message': 'Configuration updated successfully'
@@ -769,7 +956,6 @@ class APIHandler:
 
 class ServerConfigHandler:
     """服务器配置处理器"""
-
     def __init__(self, mcp_server: BaseMCPServer):
         self.mcp_server = mcp_server
         self.logger = logging.getLogger(f"{__name__}.ServerConfigHandler")
